SystemOrganization addCategory: #ConfigurationOfSignals!

Object subclass: #ConfigurationOfSignals
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSignals'!

!ConfigurationOfSignals class methodsFor: 'development support' stamp: 'DaleHenrichs 12/17/2010 10:23'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSignals class methodsFor: 'private' stamp: 'DaleHenrichs 11/2/2010 16:51'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSignals class methodsFor: 'private' stamp: 'DaleHenrichs 12/6/2010 13:34'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSignals class methodsFor: 'private' stamp: 'DaleHenrichs 11/4/2010 10:23'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSignals class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 11/2/2010 14:58'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSignals class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSignals class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSignals class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSignals class methodsFor: 'accessing' stamp: 'dkh 10/13/2009 10:36'!
project

	^self new project! !

!ConfigurationOfSignals class methodsFor: 'development support' stamp: 'DaleHenrichs 1/13/2011 15:37'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSignals methodsFor: 'baselines' stamp: 'mt 10/28/2010 19:55:29.295'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
		
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
		
		spec project: 'AXAnnouncements' with: [
			spec
				className: 'ConfigurationOfAXAnnouncements';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec
			package: 'Signals';
			package: 'MethodWrappers';
			package: 'SI-Wrapper' with: [spec requires: #('MethodWrappers' 'Signals')];
			package: 'SI-Reflection' with: [spec requires: #('Signals')];
			package: 'SI-OB-Morphic' with: [spec requires: #('OmniBrowser' 'Signals')];
			package: 'SI-Benchmarks' with: [spec requires: #('AXAnnouncements' 'SI-Wrapper' 'Signals')].
		spec
			group: 'default' with: #('Signals');
			group: 'full' with: #('Signals' 'SI-Wrapper' 'SI-Reflection' 'SI-OB-Morphic' 'SI-Benchmarks') ].! !

!ConfigurationOfSignals methodsFor: 'accessing' stamp: 'DaleHenrichs 11/5/2010 13:54'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSignals methodsFor: 'symbolic versions' stamp: 'mt 2/5/2011 17:52:38.654'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'squeak4.1.x' version: '1.0.1'.
	spec for: #'squeak4.2.x' version: '1.0.1'.! !

!ConfigurationOfSignals methodsFor: 'versions' stamp: 'mt 2/5/2011 17:42:28.131'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		
		spec
			package: 'Signals' with: 'Signals-mt.26';
			package: 'SI-Wrapper' with: 'SI-Wrapper-mt.1';
			package: 'SI-Reflection' with: 'SI-Reflection-mt.1';
			package: 'SI-OB-Morphic' with: 'SI-OB-Morphic-mt.1';
			package: 'SI-Benchmarks' with: 'SI-Benchmarks-mt.1'].! !

!ConfigurationOfSignals methodsFor: 'versions' stamp: 'mt 2/5/2011 17:42:30.502'!
version101: spec

	<version: '1.0.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		
		spec
			package: 'Signals' with: 'Signals-mt.27';
			package: 'SI-Wrapper' with: 'SI-Wrapper-mt.1';
			package: 'SI-Reflection' with: 'SI-Reflection-mt.1';
			package: 'SI-OB-Morphic' with: 'SI-OB-Morphic-mt.1';
			package: 'SI-Benchmarks' with: 'SI-Benchmarks-mt.1'].! !
